@@ -19,20 +19,13 @@ from teststack import cli
 @click.pass_context
 def env(ctx, no_export, inside, quiet):
     envvars = []
-    client = docker.from_env()
+    client = ctx.obj['client']
     for service, data in ctx.obj['services'].items():
         name = f'{ctx.obj["project_name"]}_{service}'
-        try:
-            container = client.containers.get(name)
-        except docker.errors.NotFound:
+        container_data = client.get_container_data(name, inside=inside)
+        if container_data is None:
             continue
-        container_data = data.get('environment', {}).copy()
-        container_data['HOST'] = container.attrs['NetworkSettings']['IPAddress'] if inside else 'localhost'
-        for port, port_data in container.attrs['NetworkSettings']['Ports'].items():
-            if inside:
-                container_data[f'PORT;{port}'] = port.split('/')[0]
-            elif port_data:
-                container_data[f'PORT;{port}'] = port_data[0]['HostPort']
+        container_data.update(data.get('environment', {}).copy())
         for key, value in data.get('export', {}).items():
             envvars.append(
                 f'{"" if no_export else "export "}{key}={value}'.format_map(
